# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'VpnGatewayTag',
    'GetVpnGatewayTagResult',
]

@pulumi.output_type
class VpnGatewayTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: VPN网关标签的标签键（Key）。参数   - N：表示标签键的序号，取值范围：1～20。多个标签键之间用&分隔。命名规则如下：不能以volc:或sys:的任意大小写组合开头。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。说明同一资源的标签键不允许重复。
        :param builtins.str value: VPN网关标签的标签值（Value）。参数   - N：表示标签值的序号，取值范围：1～20。多个标签值之间用&分隔。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。大小写敏感，不能以空格开头或结尾。说明传入Tags.N.Value则必须传入Tags.N.Key。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        VPN网关标签的标签键（Key）。参数   - N：表示标签键的序号，取值范围：1～20。多个标签键之间用&分隔。命名规则如下：不能以volc:或sys:的任意大小写组合开头。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。说明同一资源的标签键不允许重复。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        VPN网关标签的标签值（Value）。参数   - N：表示标签值的序号，取值范围：1～20。多个标签值之间用&分隔。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。大小写敏感，不能以空格开头或结尾。说明传入Tags.N.Value则必须传入Tags.N.Key。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetVpnGatewayTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: VPN网关标签的标签键（Key）。参数   - N：表示标签键的序号，取值范围：1～20。多个标签键之间用&分隔。命名规则如下：不能以volc:或sys:的任意大小写组合开头。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。说明同一资源的标签键不允许重复。
        :param builtins.str value: VPN网关标签的标签值（Value）。参数   - N：表示标签值的序号，取值范围：1～20。多个标签值之间用&分隔。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。大小写敏感，不能以空格开头或结尾。说明传入Tags.N.Value则必须传入Tags.N.Key。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        VPN网关标签的标签键（Key）。参数   - N：表示标签键的序号，取值范围：1～20。多个标签键之间用&分隔。命名规则如下：不能以volc:或sys:的任意大小写组合开头。只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。长度限制在1～128个字符之间。说明同一资源的标签键不允许重复。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        VPN网关标签的标签值（Value）。参数   - N：表示标签值的序号，取值范围：1～20。多个标签值之间用&分隔。命名规则如下：只能包含语言字符、数字、空格和英文符号“_”、“.”、“:”、“/”、“=”、“+”、“-”、“@”。允许为空，长度限制在0～256个字符之间。大小写敏感，不能以空格开头或结尾。说明传入Tags.N.Value则必须传入Tags.N.Key。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'RegistryProxyCacheArgs',
    'RegistryProxyCacheArgsDict',
    'RegistryStatusArgs',
    'RegistryStatusArgsDict',
    'RegistryTagArgs',
    'RegistryTagArgsDict',
]

MYPY = False

if not MYPY:
    class RegistryProxyCacheArgsDict(TypedDict):
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
elif False:
    RegistryProxyCacheArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RegistryProxyCacheArgs:
    def __init__(__self__, *,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] type: ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class RegistryStatusArgsDict(TypedDict):
        conditions: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        phase: NotRequired[pulumi.Input[builtins.str]]
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
elif False:
    RegistryStatusArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RegistryStatusArgs:
    def __init__(__self__, *,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 phase: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] conditions: Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        :param pulumi.Input[builtins.str] phase: Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if phase is not None:
            pulumi.set(__self__, "phase", phase)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def phase(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        return pulumi.get(self, "phase")

    @phase.setter
    def phase(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "phase", value)


if not MYPY:
    class RegistryTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的 Key 值。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的 Value 值列表。
        """
elif False:
    RegistryTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RegistryTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签的 Key 值。
        :param pulumi.Input[builtins.str] value: 标签的 Value 值列表。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的 Key 值。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的 Value 值列表。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NlbArgs', 'Nlb']

@pulumi.input_type
class NlbArgs:
    def __init__(__self__, *,
                 ipv4_network_type: pulumi.Input[builtins.str],
                 security_group_ids: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_mappings: pulumi.Input[Sequence[pulumi.Input['NlbZoneMappingArgs']]],
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 cross_zone_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbTagArgs']]]] = None):
        """
        The set of arguments for constructing a Nlb resource.
        :param pulumi.Input[builtins.str] ipv4_network_type: NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: NLB实例关联的安全组ID列表。
        :param pulumi.Input[builtins.str] vpc_id: NLB实例所属的VPC ID。
        :param pulumi.Input[builtins.str] account_id: NLB实例所属的账号ID。
        :param pulumi.Input[builtins.bool] cross_zone_enabled: NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        :param pulumi.Input[builtins.str] description: NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input[builtins.str] ip_address_version: NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        :param pulumi.Input[builtins.str] ipv4_bandwidth_package_id: IPv4类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv6_bandwidth_package_id: IPv6类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv6_network_type: NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] load_balancer_name: NLB实例的名称。
        :param pulumi.Input[builtins.str] modification_protection_status: NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        :param pulumi.Input[builtins.str] project_name: NLB实例所属项目的名称。
        """
        pulumi.set(__self__, "ipv4_network_type", ipv4_network_type)
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_mappings", zone_mappings)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if cross_zone_enabled is not None:
            pulumi.set(__self__, "cross_zone_enabled", cross_zone_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_address_version is not None:
            pulumi.set(__self__, "ip_address_version", ip_address_version)
        if ipv4_bandwidth_package_id is not None:
            pulumi.set(__self__, "ipv4_bandwidth_package_id", ipv4_bandwidth_package_id)
        if ipv6_bandwidth_package_id is not None:
            pulumi.set(__self__, "ipv6_bandwidth_package_id", ipv6_bandwidth_package_id)
        if ipv6_network_type is not None:
            pulumi.set(__self__, "ipv6_network_type", ipv6_network_type)
        if load_balancer_name is not None:
            pulumi.set(__self__, "load_balancer_name", load_balancer_name)
        if modification_protection_status is not None:
            pulumi.set(__self__, "modification_protection_status", modification_protection_status)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="ipv4NetworkType")
    def ipv4_network_type(self) -> pulumi.Input[builtins.str]:
        """
        NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        """
        return pulumi.get(self, "ipv4_network_type")

    @ipv4_network_type.setter
    def ipv4_network_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ipv4_network_type", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        NLB实例关联的安全组ID列表。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        NLB实例所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> pulumi.Input[Sequence[pulumi.Input['NlbZoneMappingArgs']]]:
        return pulumi.get(self, "zone_mappings")

    @zone_mappings.setter
    def zone_mappings(self, value: pulumi.Input[Sequence[pulumi.Input['NlbZoneMappingArgs']]]):
        pulumi.set(self, "zone_mappings", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="crossZoneEnabled")
    def cross_zone_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        """
        return pulumi.get(self, "cross_zone_enabled")

    @cross_zone_enabled.setter
    def cross_zone_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cross_zone_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        """
        return pulumi.get(self, "ip_address_version")

    @ip_address_version.setter
    def ip_address_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address_version", value)

    @property
    @pulumi.getter(name="ipv4BandwidthPackageId")
    def ipv4_bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv4类型的共享带宽包ID。
        """
        return pulumi.get(self, "ipv4_bandwidth_package_id")

    @ipv4_bandwidth_package_id.setter
    def ipv4_bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_bandwidth_package_id", value)

    @property
    @pulumi.getter(name="ipv6BandwidthPackageId")
    def ipv6_bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6类型的共享带宽包ID。
        """
        return pulumi.get(self, "ipv6_bandwidth_package_id")

    @ipv6_bandwidth_package_id.setter
    def ipv6_bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_bandwidth_package_id", value)

    @property
    @pulumi.getter(name="ipv6NetworkType")
    def ipv6_network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        """
        return pulumi.get(self, "ipv6_network_type")

    @ipv6_network_type.setter
    def ipv6_network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_network_type", value)

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @load_balancer_name.setter
    def load_balancer_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_name", value)

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        """
        return pulumi.get(self, "modification_protection_status")

    @modification_protection_status.setter
    def modification_protection_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modification_protection_status", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NlbState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 billing_status: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 cross_zone_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dns_name: Optional[pulumi.Input[builtins.str]] = None,
                 expected_overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 managed_security_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 reclaimed_time: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['NlbZoneMappingArgs']]]] = None):
        """
        Input properties used for looking up and filtering Nlb resources.
        :param pulumi.Input[builtins.str] account_id: NLB实例所属的账号ID。
        :param pulumi.Input[builtins.str] billing_status: NLB实例的计费状态。Normal: 正常，FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.int] billing_type: NLB实例的计费类型。3：按使用量计费
        :param pulumi.Input[builtins.str] created_time: NLB实例的创建时间。
        :param pulumi.Input[builtins.bool] cross_zone_enabled: NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        :param pulumi.Input[builtins.str] description: NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input[builtins.str] dns_name: NLB实例的DNS地址。
        :param pulumi.Input[builtins.str] expected_overdue_time: NLB实例欠费关停时间。
        :param pulumi.Input[builtins.str] ip_address_version: NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        :param pulumi.Input[builtins.str] ipv4_bandwidth_package_id: IPv4类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv4_network_type: NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] ipv6_bandwidth_package_id: IPv6类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv6_network_type: NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] load_balancer_id: NLB实例ID。
        :param pulumi.Input[builtins.str] load_balancer_name: NLB实例的名称。
        :param pulumi.Input[builtins.str] managed_security_group_id: 系统为NLB实例自动关联的托管安全组ID。
        :param pulumi.Input[builtins.str] modification_protection_status: NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        :param pulumi.Input[builtins.str] overdue_time: NLB实例被锁定的时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        :param pulumi.Input[builtins.str] project_name: NLB实例所属项目的名称。
        :param pulumi.Input[builtins.str] reclaimed_time: NLB实例的预期回收时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: NLB实例关联的安全组ID列表。
        :param pulumi.Input[builtins.str] status: NLB 实例的状态。Inactive：已停止。Active：运行中。Creating：创建中。Provisioning：创建中。仅调用API创建NLB实例时存在该状态。Configuring：配置中。Deleting：删除中。CreateFailed：创建失败。
        :param pulumi.Input[builtins.str] updated_time: NLB实例的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: NLB实例所属的VPC ID。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if billing_status is not None:
            pulumi.set(__self__, "billing_status", billing_status)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if cross_zone_enabled is not None:
            pulumi.set(__self__, "cross_zone_enabled", cross_zone_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dns_name is not None:
            pulumi.set(__self__, "dns_name", dns_name)
        if expected_overdue_time is not None:
            pulumi.set(__self__, "expected_overdue_time", expected_overdue_time)
        if ip_address_version is not None:
            pulumi.set(__self__, "ip_address_version", ip_address_version)
        if ipv4_bandwidth_package_id is not None:
            pulumi.set(__self__, "ipv4_bandwidth_package_id", ipv4_bandwidth_package_id)
        if ipv4_network_type is not None:
            pulumi.set(__self__, "ipv4_network_type", ipv4_network_type)
        if ipv6_bandwidth_package_id is not None:
            pulumi.set(__self__, "ipv6_bandwidth_package_id", ipv6_bandwidth_package_id)
        if ipv6_network_type is not None:
            pulumi.set(__self__, "ipv6_network_type", ipv6_network_type)
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if load_balancer_name is not None:
            pulumi.set(__self__, "load_balancer_name", load_balancer_name)
        if managed_security_group_id is not None:
            pulumi.set(__self__, "managed_security_group_id", managed_security_group_id)
        if modification_protection_status is not None:
            pulumi.set(__self__, "modification_protection_status", modification_protection_status)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if reclaimed_time is not None:
            pulumi.set(__self__, "reclaimed_time", reclaimed_time)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_mappings is not None:
            pulumi.set(__self__, "zone_mappings", zone_mappings)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="billingStatus")
    def billing_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的计费状态。Normal: 正常，FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "billing_status")

    @billing_status.setter
    def billing_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_status", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        NLB实例的计费类型。3：按使用量计费
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="crossZoneEnabled")
    def cross_zone_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        """
        return pulumi.get(self, "cross_zone_enabled")

    @cross_zone_enabled.setter
    def cross_zone_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "cross_zone_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的DNS地址。
        """
        return pulumi.get(self, "dns_name")

    @dns_name.setter
    def dns_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dns_name", value)

    @property
    @pulumi.getter(name="expectedOverdueTime")
    def expected_overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例欠费关停时间。
        """
        return pulumi.get(self, "expected_overdue_time")

    @expected_overdue_time.setter
    def expected_overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expected_overdue_time", value)

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        """
        return pulumi.get(self, "ip_address_version")

    @ip_address_version.setter
    def ip_address_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address_version", value)

    @property
    @pulumi.getter(name="ipv4BandwidthPackageId")
    def ipv4_bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv4类型的共享带宽包ID。
        """
        return pulumi.get(self, "ipv4_bandwidth_package_id")

    @ipv4_bandwidth_package_id.setter
    def ipv4_bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_bandwidth_package_id", value)

    @property
    @pulumi.getter(name="ipv4NetworkType")
    def ipv4_network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        """
        return pulumi.get(self, "ipv4_network_type")

    @ipv4_network_type.setter
    def ipv4_network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_network_type", value)

    @property
    @pulumi.getter(name="ipv6BandwidthPackageId")
    def ipv6_bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv6类型的共享带宽包ID。
        """
        return pulumi.get(self, "ipv6_bandwidth_package_id")

    @ipv6_bandwidth_package_id.setter
    def ipv6_bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_bandwidth_package_id", value)

    @property
    @pulumi.getter(name="ipv6NetworkType")
    def ipv6_network_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        """
        return pulumi.get(self, "ipv6_network_type")

    @ipv6_network_type.setter
    def ipv6_network_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_network_type", value)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @load_balancer_name.setter
    def load_balancer_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_name", value)

    @property
    @pulumi.getter(name="managedSecurityGroupId")
    def managed_security_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        系统为NLB实例自动关联的托管安全组ID。
        """
        return pulumi.get(self, "managed_security_group_id")

    @managed_security_group_id.setter
    def managed_security_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "managed_security_group_id", value)

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        """
        return pulumi.get(self, "modification_protection_status")

    @modification_protection_status.setter
    def modification_protection_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modification_protection_status", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例被锁定的时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="reclaimedTime")
    def reclaimed_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的预期回收时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        """
        return pulumi.get(self, "reclaimed_time")

    @reclaimed_time.setter
    def reclaimed_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "reclaimed_time", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        NLB实例关联的安全组ID列表。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB 实例的状态。Inactive：已停止。Active：运行中。Creating：创建中。Provisioning：创建中。仅调用API创建NLB实例时存在该状态。Configuring：配置中。Deleting：删除中。CreateFailed：创建失败。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NLB实例所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbZoneMappingArgs']]]]:
        return pulumi.get(self, "zone_mappings")

    @zone_mappings.setter
    def zone_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbZoneMappingArgs']]]]):
        pulumi.set(self, "zone_mappings", value)


@pulumi.type_token("bytepluscc:clb/nlb:Nlb")
class Nlb(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 cross_zone_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbTagArgs', 'NlbTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbZoneMappingArgs', 'NlbZoneMappingArgsDict']]]]] = None,
                 __props__=None):
        """
        NLB 实例用于接收用户的访问请求，并根据监听器和服务器组的配置设定，将访问请求转发至后端服务器。

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlb:Nlb example "load_balancer_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: NLB实例所属的账号ID。
        :param pulumi.Input[builtins.bool] cross_zone_enabled: NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        :param pulumi.Input[builtins.str] description: NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input[builtins.str] ip_address_version: NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        :param pulumi.Input[builtins.str] ipv4_bandwidth_package_id: IPv4类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv4_network_type: NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] ipv6_bandwidth_package_id: IPv6类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv6_network_type: NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] load_balancer_name: NLB实例的名称。
        :param pulumi.Input[builtins.str] modification_protection_status: NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        :param pulumi.Input[builtins.str] project_name: NLB实例所属项目的名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: NLB实例关联的安全组ID列表。
        :param pulumi.Input[builtins.str] vpc_id: NLB实例所属的VPC ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NlbArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        NLB 实例用于接收用户的访问请求，并根据监听器和服务器组的配置设定，将访问请求转发至后端服务器。

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlb:Nlb example "load_balancer_id"
        ```

        :param str resource_name: The name of the resource.
        :param NlbArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NlbArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 cross_zone_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_network_type: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
                 modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbTagArgs', 'NlbTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbZoneMappingArgs', 'NlbZoneMappingArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NlbArgs.__new__(NlbArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["cross_zone_enabled"] = cross_zone_enabled
            __props__.__dict__["description"] = description
            __props__.__dict__["ip_address_version"] = ip_address_version
            __props__.__dict__["ipv4_bandwidth_package_id"] = ipv4_bandwidth_package_id
            if ipv4_network_type is None and not opts.urn:
                raise TypeError("Missing required property 'ipv4_network_type'")
            __props__.__dict__["ipv4_network_type"] = ipv4_network_type
            __props__.__dict__["ipv6_bandwidth_package_id"] = ipv6_bandwidth_package_id
            __props__.__dict__["ipv6_network_type"] = ipv6_network_type
            __props__.__dict__["load_balancer_name"] = load_balancer_name
            __props__.__dict__["modification_protection_status"] = modification_protection_status
            __props__.__dict__["project_name"] = project_name
            if security_group_ids is None and not opts.urn:
                raise TypeError("Missing required property 'security_group_ids'")
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_mappings is None and not opts.urn:
                raise TypeError("Missing required property 'zone_mappings'")
            __props__.__dict__["zone_mappings"] = zone_mappings
            __props__.__dict__["billing_status"] = None
            __props__.__dict__["billing_type"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["dns_name"] = None
            __props__.__dict__["expected_overdue_time"] = None
            __props__.__dict__["load_balancer_id"] = None
            __props__.__dict__["managed_security_group_id"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["reclaimed_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(Nlb, __self__).__init__(
            'bytepluscc:clb/nlb:Nlb',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            billing_status: Optional[pulumi.Input[builtins.str]] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            cross_zone_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dns_name: Optional[pulumi.Input[builtins.str]] = None,
            expected_overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            ip_address_version: Optional[pulumi.Input[builtins.str]] = None,
            ipv4_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
            ipv4_network_type: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_network_type: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_name: Optional[pulumi.Input[builtins.str]] = None,
            managed_security_group_id: Optional[pulumi.Input[builtins.str]] = None,
            modification_protection_status: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            reclaimed_time: Optional[pulumi.Input[builtins.str]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbTagArgs', 'NlbTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbZoneMappingArgs', 'NlbZoneMappingArgsDict']]]]] = None) -> 'Nlb':
        """
        Get an existing Nlb resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: NLB实例所属的账号ID。
        :param pulumi.Input[builtins.str] billing_status: NLB实例的计费状态。Normal: 正常，FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.int] billing_type: NLB实例的计费类型。3：按使用量计费
        :param pulumi.Input[builtins.str] created_time: NLB实例的创建时间。
        :param pulumi.Input[builtins.bool] cross_zone_enabled: NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        :param pulumi.Input[builtins.str] description: NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        :param pulumi.Input[builtins.str] dns_name: NLB实例的DNS地址。
        :param pulumi.Input[builtins.str] expected_overdue_time: NLB实例欠费关停时间。
        :param pulumi.Input[builtins.str] ip_address_version: NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        :param pulumi.Input[builtins.str] ipv4_bandwidth_package_id: IPv4类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv4_network_type: NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] ipv6_bandwidth_package_id: IPv6类型的共享带宽包ID。
        :param pulumi.Input[builtins.str] ipv6_network_type: NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        :param pulumi.Input[builtins.str] load_balancer_id: NLB实例ID。
        :param pulumi.Input[builtins.str] load_balancer_name: NLB实例的名称。
        :param pulumi.Input[builtins.str] managed_security_group_id: 系统为NLB实例自动关联的托管安全组ID。
        :param pulumi.Input[builtins.str] modification_protection_status: NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        :param pulumi.Input[builtins.str] overdue_time: NLB实例被锁定的时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        :param pulumi.Input[builtins.str] project_name: NLB实例所属项目的名称。
        :param pulumi.Input[builtins.str] reclaimed_time: NLB实例的预期回收时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: NLB实例关联的安全组ID列表。
        :param pulumi.Input[builtins.str] status: NLB 实例的状态。Inactive：已停止。Active：运行中。Creating：创建中。Provisioning：创建中。仅调用API创建NLB实例时存在该状态。Configuring：配置中。Deleting：删除中。CreateFailed：创建失败。
        :param pulumi.Input[builtins.str] updated_time: NLB实例的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: NLB实例所属的VPC ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NlbState.__new__(_NlbState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["billing_status"] = billing_status
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["cross_zone_enabled"] = cross_zone_enabled
        __props__.__dict__["description"] = description
        __props__.__dict__["dns_name"] = dns_name
        __props__.__dict__["expected_overdue_time"] = expected_overdue_time
        __props__.__dict__["ip_address_version"] = ip_address_version
        __props__.__dict__["ipv4_bandwidth_package_id"] = ipv4_bandwidth_package_id
        __props__.__dict__["ipv4_network_type"] = ipv4_network_type
        __props__.__dict__["ipv6_bandwidth_package_id"] = ipv6_bandwidth_package_id
        __props__.__dict__["ipv6_network_type"] = ipv6_network_type
        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["load_balancer_name"] = load_balancer_name
        __props__.__dict__["managed_security_group_id"] = managed_security_group_id
        __props__.__dict__["modification_protection_status"] = modification_protection_status
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["reclaimed_time"] = reclaimed_time
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_mappings"] = zone_mappings
        return Nlb(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="billingStatus")
    def billing_status(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的计费状态。Normal: 正常，FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "billing_status")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        NLB实例的计费类型。3：按使用量计费
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="crossZoneEnabled")
    def cross_zone_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        NLB实例是否开启跨可用区转发能力。true（默认值）：开启。false：关闭。
        """
        return pulumi.get(self, "cross_zone_enabled")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的DNS地址。
        """
        return pulumi.get(self, "dns_name")

    @property
    @pulumi.getter(name="expectedOverdueTime")
    def expected_overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例欠费关停时间。
        """
        return pulumi.get(self, "expected_overdue_time")

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的IP地址类型。ipv4：IPv4版本。dualstack：双栈，即同时支持IPv4版本和IPv6版本。
        """
        return pulumi.get(self, "ip_address_version")

    @property
    @pulumi.getter(name="ipv4BandwidthPackageId")
    def ipv4_bandwidth_package_id(self) -> pulumi.Output[builtins.str]:
        """
        IPv4类型的共享带宽包ID。
        """
        return pulumi.get(self, "ipv4_bandwidth_package_id")

    @property
    @pulumi.getter(name="ipv4NetworkType")
    def ipv4_network_type(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的IPv4网络类型。internet：公网类型。intranet：私网类型。
        """
        return pulumi.get(self, "ipv4_network_type")

    @property
    @pulumi.getter(name="ipv6BandwidthPackageId")
    def ipv6_bandwidth_package_id(self) -> pulumi.Output[builtins.str]:
        """
        IPv6类型的共享带宽包ID。
        """
        return pulumi.get(self, "ipv6_bandwidth_package_id")

    @property
    @pulumi.getter(name="ipv6NetworkType")
    def ipv6_network_type(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的IPv6网络类型。internet：公网类型。intranet：私网类型。
        """
        return pulumi.get(self, "ipv6_network_type")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @property
    @pulumi.getter(name="managedSecurityGroupId")
    def managed_security_group_id(self) -> pulumi.Output[builtins.str]:
        """
        系统为NLB实例自动关联的托管安全组ID。
        """
        return pulumi.get(self, "managed_security_group_id")

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例是否开启控制台上修改保护。NonProtection或空：关闭，允许通过控制台修改实例或删除实例。ConsoleProtection：开启，禁止通过控制台修改实例或删除实例。
        """
        return pulumi.get(self, "modification_protection_status")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例被锁定的时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="reclaimedTime")
    def reclaimed_time(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的预期回收时间。参数BillingStatus为Normal时，本参数返回为空字符串。
        """
        return pulumi.get(self, "reclaimed_time")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        NLB实例关联的安全组ID列表。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        NLB 实例的状态。Inactive：已停止。Active：运行中。Creating：创建中。Provisioning：创建中。仅调用API创建NLB实例时存在该状态。Configuring：配置中。Deleting：删除中。CreateFailed：创建失败。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NlbTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        NLB实例所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> pulumi.Output[Sequence['outputs.NlbZoneMapping']]:
        return pulumi.get(self, "zone_mappings")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBandwidthPackageResult',
    'AwaitableGetBandwidthPackageResult',
    'get_bandwidth_package',
    'get_bandwidth_package_output',
]

@pulumi.output_type
class GetBandwidthPackageResult:
    """
    A collection of values returned by getBandwidthPackage.
    """
    def __init__(__self__, bandwidth=None, bandwidth_package_id=None, bandwidth_package_name=None, billing_type=None, business_status=None, created_time=None, deleted_time=None, description=None, eip_addresses=None, enable_dual_stack=None, expired_time=None, id=None, isp=None, overdue_time=None, period=None, period_unit=None, project_name=None, protocol=None, ratio=None, security_protection_types=None, status=None, tags=None, updated_time=None):
        if bandwidth and not isinstance(bandwidth, int):
            raise TypeError("Expected argument 'bandwidth' to be a int")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id and not isinstance(bandwidth_package_id, str):
            raise TypeError("Expected argument 'bandwidth_package_id' to be a str")
        pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if bandwidth_package_name and not isinstance(bandwidth_package_name, str):
            raise TypeError("Expected argument 'bandwidth_package_name' to be a str")
        pulumi.set(__self__, "bandwidth_package_name", bandwidth_package_name)
        if billing_type and not isinstance(billing_type, int):
            raise TypeError("Expected argument 'billing_type' to be a int")
        pulumi.set(__self__, "billing_type", billing_type)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if eip_addresses and not isinstance(eip_addresses, list):
            raise TypeError("Expected argument 'eip_addresses' to be a list")
        pulumi.set(__self__, "eip_addresses", eip_addresses)
        if enable_dual_stack and not isinstance(enable_dual_stack, bool):
            raise TypeError("Expected argument 'enable_dual_stack' to be a bool")
        pulumi.set(__self__, "enable_dual_stack", enable_dual_stack)
        if expired_time and not isinstance(expired_time, str):
            raise TypeError("Expected argument 'expired_time' to be a str")
        pulumi.set(__self__, "expired_time", expired_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if isp and not isinstance(isp, str):
            raise TypeError("Expected argument 'isp' to be a str")
        pulumi.set(__self__, "isp", isp)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if period and not isinstance(period, int):
            raise TypeError("Expected argument 'period' to be a int")
        pulumi.set(__self__, "period", period)
        if period_unit and not isinstance(period_unit, int):
            raise TypeError("Expected argument 'period_unit' to be a int")
        pulumi.set(__self__, "period_unit", period_unit)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if ratio and not isinstance(ratio, int):
            raise TypeError("Expected argument 'ratio' to be a int")
        pulumi.set(__self__, "ratio", ratio)
        if security_protection_types and not isinstance(security_protection_types, list):
            raise TypeError("Expected argument 'security_protection_types' to be a list")
        pulumi.set(__self__, "security_protection_types", security_protection_types)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.int:
        """
        共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> builtins.str:
        """
        带宽包ID
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="bandwidthPackageName")
    def bandwidth_package_name(self) -> builtins.str:
        """
        带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "bandwidth_package_name")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.int:
        """
        共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        计费状态
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> Sequence['outputs.GetBandwidthPackageEipAddressResult']:
        """
        加入共享带宽包的公网IP信息列表。必须同时满足如下条件：1、二者线路类型相同。2、二者安全防护类型相同。3、二者地域相同。4、公网IP或IPv6公网带宽为按量计费。
        """
        return pulumi.get(self, "eip_addresses")

    @property
    @pulumi.getter(name="enableDualStack")
    def enable_dual_stack(self) -> builtins.bool:
        """
        是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        """
        return pulumi.get(self, "enable_dual_stack")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> builtins.str:
        """
        过期时间
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def isp(self) -> builtins.str:
        """
        线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        欠费时间
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> builtins.int:
        """
        购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> builtins.int:
        """
        购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def ratio(self) -> builtins.int:
        """
        95计费保底比例，单位%，仅95计费共享带宽包实例返回此参数。
        """
        return pulumi.get(self, "ratio")

    @property
    @pulumi.getter(name="securityProtectionTypes")
    def security_protection_types(self) -> Sequence[builtins.str]:
        """
        共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        """
        return pulumi.get(self, "security_protection_types")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        共享带宽包的状态。Creating：创建中。Available：可用。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetBandwidthPackageTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetBandwidthPackageResult(GetBandwidthPackageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBandwidthPackageResult(
            bandwidth=self.bandwidth,
            bandwidth_package_id=self.bandwidth_package_id,
            bandwidth_package_name=self.bandwidth_package_name,
            billing_type=self.billing_type,
            business_status=self.business_status,
            created_time=self.created_time,
            deleted_time=self.deleted_time,
            description=self.description,
            eip_addresses=self.eip_addresses,
            enable_dual_stack=self.enable_dual_stack,
            expired_time=self.expired_time,
            id=self.id,
            isp=self.isp,
            overdue_time=self.overdue_time,
            period=self.period,
            period_unit=self.period_unit,
            project_name=self.project_name,
            protocol=self.protocol,
            ratio=self.ratio,
            security_protection_types=self.security_protection_types,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_bandwidth_package(id: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBandwidthPackageResult:
    """
    Data Source schema for Byteplus::VPC::BandwidthPackage


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getBandwidthPackage:getBandwidthPackage', __args__, opts=opts, typ=GetBandwidthPackageResult).value

    return AwaitableGetBandwidthPackageResult(
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        bandwidth_package_id=pulumi.get(__ret__, 'bandwidth_package_id'),
        bandwidth_package_name=pulumi.get(__ret__, 'bandwidth_package_name'),
        billing_type=pulumi.get(__ret__, 'billing_type'),
        business_status=pulumi.get(__ret__, 'business_status'),
        created_time=pulumi.get(__ret__, 'created_time'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        eip_addresses=pulumi.get(__ret__, 'eip_addresses'),
        enable_dual_stack=pulumi.get(__ret__, 'enable_dual_stack'),
        expired_time=pulumi.get(__ret__, 'expired_time'),
        id=pulumi.get(__ret__, 'id'),
        isp=pulumi.get(__ret__, 'isp'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        period=pulumi.get(__ret__, 'period'),
        period_unit=pulumi.get(__ret__, 'period_unit'),
        project_name=pulumi.get(__ret__, 'project_name'),
        protocol=pulumi.get(__ret__, 'protocol'),
        ratio=pulumi.get(__ret__, 'ratio'),
        security_protection_types=pulumi.get(__ret__, 'security_protection_types'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_bandwidth_package_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBandwidthPackageResult]:
    """
    Data Source schema for Byteplus::VPC::BandwidthPackage


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getBandwidthPackage:getBandwidthPackage', __args__, opts=opts, typ=GetBandwidthPackageResult)
    return __ret__.apply(lambda __response__: GetBandwidthPackageResult(
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        bandwidth_package_id=pulumi.get(__response__, 'bandwidth_package_id'),
        bandwidth_package_name=pulumi.get(__response__, 'bandwidth_package_name'),
        billing_type=pulumi.get(__response__, 'billing_type'),
        business_status=pulumi.get(__response__, 'business_status'),
        created_time=pulumi.get(__response__, 'created_time'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        eip_addresses=pulumi.get(__response__, 'eip_addresses'),
        enable_dual_stack=pulumi.get(__response__, 'enable_dual_stack'),
        expired_time=pulumi.get(__response__, 'expired_time'),
        id=pulumi.get(__response__, 'id'),
        isp=pulumi.get(__response__, 'isp'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        period=pulumi.get(__response__, 'period'),
        period_unit=pulumi.get(__response__, 'period_unit'),
        project_name=pulumi.get(__response__, 'project_name'),
        protocol=pulumi.get(__response__, 'protocol'),
        ratio=pulumi.get(__response__, 'ratio'),
        security_protection_types=pulumi.get(__response__, 'security_protection_types'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GroupResetInfoArgs',
    'GroupResetInfoArgsDict',
    'GroupTopicInfoArgs',
    'GroupTopicInfoArgsDict',
    'GroupTopicInfoPartitionInfoArgs',
    'GroupTopicInfoPartitionInfoArgsDict',
    'InstanceEndpointsArgs',
    'InstanceEndpointsArgsDict',
    'InstanceEndpointsOverlayArgs',
    'InstanceEndpointsOverlayArgsDict',
    'InstanceEndpointsPublicArgs',
    'InstanceEndpointsPublicArgsDict',
    'InstanceResourceTagArgs',
    'InstanceResourceTagArgsDict',
    'InstanceResourceTagTagKvArgs',
    'InstanceResourceTagTagKvArgsDict',
    'InstanceResourcesArgs',
    'InstanceResourcesArgsDict',
    'InstanceResourcesStorageArgs',
    'InstanceResourcesStorageArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
]

MYPY = False

if not MYPY:
    class GroupResetInfoArgsDict(TypedDict):
        offset_type: NotRequired[pulumi.Input[builtins.str]]
        """
        重置方式为 OFFSET 时，该参数必传，指定重新消费的基准消费位置，取值如下：EARLIEST：基准消费位置为最早消费位点。CURRENT：基准消费位置为当前消费位点。LATEST：基准消费位置为最近消费位点。
        """
        partition_id: NotRequired[pulumi.Input[builtins.int]]
        """
        分区序号。
        """
        reset_by: NotRequired[pulumi.Input[builtins.str]]
        """
        重置方式，取值如下：TIMESTAMP：根据时间点重置消费位点，指定过去或将来的时间点，直接跳转到该时间点的位点开始消费。OFFSET：根据指定的 offset 重置消费位点，即从指定的位点开始消费，可以通过 offsetType 参数指定 offset。
        """
        reset_value: NotRequired[pulumi.Input[builtins.int]]
        """
        重置值。选择重置方式为 TIMESTAMP 时，该值为重新消费的时间点。例如 1722224612000。选择重置方式为 OFFSET 时，该值为相对于 OffsetType 中基准位点的 相对偏移量。例如 100。
        """
        topic_id: NotRequired[pulumi.Input[builtins.str]]
        """
        Topic ID。
        """
elif False:
    GroupResetInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GroupResetInfoArgs:
    def __init__(__self__, *,
                 offset_type: Optional[pulumi.Input[builtins.str]] = None,
                 partition_id: Optional[pulumi.Input[builtins.int]] = None,
                 reset_by: Optional[pulumi.Input[builtins.str]] = None,
                 reset_value: Optional[pulumi.Input[builtins.int]] = None,
                 topic_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] offset_type: 重置方式为 OFFSET 时，该参数必传，指定重新消费的基准消费位置，取值如下：EARLIEST：基准消费位置为最早消费位点。CURRENT：基准消费位置为当前消费位点。LATEST：基准消费位置为最近消费位点。
        :param pulumi.Input[builtins.int] partition_id: 分区序号。
        :param pulumi.Input[builtins.str] reset_by: 重置方式，取值如下：TIMESTAMP：根据时间点重置消费位点，指定过去或将来的时间点，直接跳转到该时间点的位点开始消费。OFFSET：根据指定的 offset 重置消费位点，即从指定的位点开始消费，可以通过 offsetType 参数指定 offset。
        :param pulumi.Input[builtins.int] reset_value: 重置值。选择重置方式为 TIMESTAMP 时，该值为重新消费的时间点。例如 1722224612000。选择重置方式为 OFFSET 时，该值为相对于 OffsetType 中基准位点的 相对偏移量。例如 100。
        :param pulumi.Input[builtins.str] topic_id: Topic ID。
        """
        if offset_type is not None:
            pulumi.set(__self__, "offset_type", offset_type)
        if partition_id is not None:
            pulumi.set(__self__, "partition_id", partition_id)
        if reset_by is not None:
            pulumi.set(__self__, "reset_by", reset_by)
        if reset_value is not None:
            pulumi.set(__self__, "reset_value", reset_value)
        if topic_id is not None:
            pulumi.set(__self__, "topic_id", topic_id)

    @property
    @pulumi.getter(name="offsetType")
    def offset_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        重置方式为 OFFSET 时，该参数必传，指定重新消费的基准消费位置，取值如下：EARLIEST：基准消费位置为最早消费位点。CURRENT：基准消费位置为当前消费位点。LATEST：基准消费位置为最近消费位点。
        """
        return pulumi.get(self, "offset_type")

    @offset_type.setter
    def offset_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "offset_type", value)

    @property
    @pulumi.getter(name="partitionId")
    def partition_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        分区序号。
        """
        return pulumi.get(self, "partition_id")

    @partition_id.setter
    def partition_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_id", value)

    @property
    @pulumi.getter(name="resetBy")
    def reset_by(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        重置方式，取值如下：TIMESTAMP：根据时间点重置消费位点，指定过去或将来的时间点，直接跳转到该时间点的位点开始消费。OFFSET：根据指定的 offset 重置消费位点，即从指定的位点开始消费，可以通过 offsetType 参数指定 offset。
        """
        return pulumi.get(self, "reset_by")

    @reset_by.setter
    def reset_by(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "reset_by", value)

    @property
    @pulumi.getter(name="resetValue")
    def reset_value(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        重置值。选择重置方式为 TIMESTAMP 时，该值为重新消费的时间点。例如 1722224612000。选择重置方式为 OFFSET 时，该值为相对于 OffsetType 中基准位点的 相对偏移量。例如 100。
        """
        return pulumi.get(self, "reset_value")

    @reset_value.setter
    def reset_value(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "reset_value", value)

    @property
    @pulumi.getter(name="topicId")
    def topic_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic ID。
        """
        return pulumi.get(self, "topic_id")

    @topic_id.setter
    def topic_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_id", value)


if not MYPY:
    class GroupTopicInfoArgsDict(TypedDict):
        create_time: NotRequired[pulumi.Input[builtins.str]]
        """
        Topic 的创建时间。
        """
        description: NotRequired[pulumi.Input[builtins.str]]
        """
        Topic 的描述语句。
        """
        lag: NotRequired[pulumi.Input[builtins.int]]
        """
        Topic 中未被消费的消息条数。
        """
        partition_infos: NotRequired[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoPartitionInfoArgsDict']]]]
        partitions: NotRequired[pulumi.Input[builtins.int]]
        """
        Topic 分区数。
        """
        retention: NotRequired[pulumi.Input[builtins.int]]
        """
        数据在 Topic 中的保留时长，单位为小时。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        Topic 的状态。
        """
        topic_id: NotRequired[pulumi.Input[builtins.str]]
        """
        Topic ID。
        """
        topic_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Topic 的名称。
        """
elif False:
    GroupTopicInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GroupTopicInfoArgs:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 lag: Optional[pulumi.Input[builtins.int]] = None,
                 partition_infos: Optional[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoPartitionInfoArgs']]]] = None,
                 partitions: Optional[pulumi.Input[builtins.int]] = None,
                 retention: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 topic_id: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] create_time: Topic 的创建时间。
        :param pulumi.Input[builtins.str] description: Topic 的描述语句。
        :param pulumi.Input[builtins.int] lag: Topic 中未被消费的消息条数。
        :param pulumi.Input[builtins.int] partitions: Topic 分区数。
        :param pulumi.Input[builtins.int] retention: 数据在 Topic 中的保留时长，单位为小时。
        :param pulumi.Input[builtins.str] status: Topic 的状态。
        :param pulumi.Input[builtins.str] topic_id: Topic ID。
        :param pulumi.Input[builtins.str] topic_name: Topic 的名称。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if lag is not None:
            pulumi.set(__self__, "lag", lag)
        if partition_infos is not None:
            pulumi.set(__self__, "partition_infos", partition_infos)
        if partitions is not None:
            pulumi.set(__self__, "partitions", partitions)
        if retention is not None:
            pulumi.set(__self__, "retention", retention)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if topic_id is not None:
            pulumi.set(__self__, "topic_id", topic_id)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的描述语句。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def lag(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Topic 中未被消费的消息条数。
        """
        return pulumi.get(self, "lag")

    @lag.setter
    def lag(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "lag", value)

    @property
    @pulumi.getter(name="partitionInfos")
    def partition_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoPartitionInfoArgs']]]]:
        return pulumi.get(self, "partition_infos")

    @partition_infos.setter
    def partition_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupTopicInfoPartitionInfoArgs']]]]):
        pulumi.set(self, "partition_infos", value)

    @property
    @pulumi.getter
    def partitions(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Topic 分区数。
        """
        return pulumi.get(self, "partitions")

    @partitions.setter
    def partitions(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partitions", value)

    @property
    @pulumi.getter
    def retention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        数据在 Topic 中的保留时长，单位为小时。
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retention", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="topicId")
    def topic_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic ID。
        """
        return pulumi.get(self, "topic_id")

    @topic_id.setter
    def topic_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_id", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Topic 的名称。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_name", value)


if not MYPY:
    class GroupTopicInfoPartitionInfoArgsDict(TypedDict):
        current_offset: NotRequired[pulumi.Input[builtins.int]]
        """
        当前消费位点。
        """
        group_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Consumer Group 的名称。
        """
        lag: NotRequired[pulumi.Input[builtins.int]]
        """
        分区中未被消费的消息条数。
        """
        latest_offset: NotRequired[pulumi.Input[builtins.int]]
        """
        最新消费位点。
        """
        partition_id: NotRequired[pulumi.Input[builtins.int]]
        """
        分区序号。
        """
        topic_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Consumer Group 订阅的 Topic 名称。
        """
elif False:
    GroupTopicInfoPartitionInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GroupTopicInfoPartitionInfoArgs:
    def __init__(__self__, *,
                 current_offset: Optional[pulumi.Input[builtins.int]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 lag: Optional[pulumi.Input[builtins.int]] = None,
                 latest_offset: Optional[pulumi.Input[builtins.int]] = None,
                 partition_id: Optional[pulumi.Input[builtins.int]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] current_offset: 当前消费位点。
        :param pulumi.Input[builtins.str] group_name: Consumer Group 的名称。
        :param pulumi.Input[builtins.int] lag: 分区中未被消费的消息条数。
        :param pulumi.Input[builtins.int] latest_offset: 最新消费位点。
        :param pulumi.Input[builtins.int] partition_id: 分区序号。
        :param pulumi.Input[builtins.str] topic_name: Consumer Group 订阅的 Topic 名称。
        """
        if current_offset is not None:
            pulumi.set(__self__, "current_offset", current_offset)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if lag is not None:
            pulumi.set(__self__, "lag", lag)
        if latest_offset is not None:
            pulumi.set(__self__, "latest_offset", latest_offset)
        if partition_id is not None:
            pulumi.set(__self__, "partition_id", partition_id)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)

    @property
    @pulumi.getter(name="currentOffset")
    def current_offset(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当前消费位点。
        """
        return pulumi.get(self, "current_offset")

    @current_offset.setter
    def current_offset(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "current_offset", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 的名称。
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter
    def lag(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        分区中未被消费的消息条数。
        """
        return pulumi.get(self, "lag")

    @lag.setter
    def lag(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "lag", value)

    @property
    @pulumi.getter(name="latestOffset")
    def latest_offset(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最新消费位点。
        """
        return pulumi.get(self, "latest_offset")

    @latest_offset.setter
    def latest_offset(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "latest_offset", value)

    @property
    @pulumi.getter(name="partitionId")
    def partition_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        分区序号。
        """
        return pulumi.get(self, "partition_id")

    @partition_id.setter
    def partition_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_id", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consumer Group 订阅的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_name", value)


if not MYPY:
    class InstanceEndpointsArgsDict(TypedDict):
        overlay: NotRequired[pulumi.Input['InstanceEndpointsOverlayArgsDict']]
        """
        实例私网访问接入点响应数据。
        """
        public: NotRequired[pulumi.Input['InstanceEndpointsPublicArgsDict']]
        """
        实例公网访问接入点响应数据。
        """
elif False:
    InstanceEndpointsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointsArgs:
    def __init__(__self__, *,
                 overlay: Optional[pulumi.Input['InstanceEndpointsOverlayArgs']] = None,
                 public: Optional[pulumi.Input['InstanceEndpointsPublicArgs']] = None):
        """
        :param pulumi.Input['InstanceEndpointsOverlayArgs'] overlay: 实例私网访问接入点响应数据。
        :param pulumi.Input['InstanceEndpointsPublicArgs'] public: 实例公网访问接入点响应数据。
        """
        if overlay is not None:
            pulumi.set(__self__, "overlay", overlay)
        if public is not None:
            pulumi.set(__self__, "public", public)

    @property
    @pulumi.getter
    def overlay(self) -> Optional[pulumi.Input['InstanceEndpointsOverlayArgs']]:
        """
        实例私网访问接入点响应数据。
        """
        return pulumi.get(self, "overlay")

    @overlay.setter
    def overlay(self, value: Optional[pulumi.Input['InstanceEndpointsOverlayArgs']]):
        pulumi.set(self, "overlay", value)

    @property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input['InstanceEndpointsPublicArgs']]:
        """
        实例公网访问接入点响应数据。
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input['InstanceEndpointsPublicArgs']]):
        pulumi.set(self, "public", value)


if not MYPY:
    class InstanceEndpointsOverlayArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[builtins.str]]
        """
        域名映射地址。
        """
        eip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        实例绑定的EIP的ID。
        """
        plain: NotRequired[pulumi.Input[builtins.str]]
        """
        私网Plain接入点。
        """
        plain_port: NotRequired[pulumi.Input[builtins.int]]
        """
        普通接入点端口。
        """
        sasl: NotRequired[pulumi.Input[builtins.str]]
        """
        私网SASL认证接入点。
        """
        sasl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        认证接入点端口。
        """
        ssl: NotRequired[pulumi.Input[builtins.str]]
        """
        加密接入点。
        """
        ssl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        加密接入点端口。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        接入点状态。
        """
        vpc_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        售卖区网络关联的VPC ID列表。
        """
elif False:
    InstanceEndpointsOverlayArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointsOverlayArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 plain: Optional[pulumi.Input[builtins.str]] = None,
                 plain_port: Optional[pulumi.Input[builtins.int]] = None,
                 sasl: Optional[pulumi.Input[builtins.str]] = None,
                 sasl_port: Optional[pulumi.Input[builtins.int]] = None,
                 ssl: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_port: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.str] address: 域名映射地址。
        :param pulumi.Input[builtins.str] eip_id: 实例绑定的EIP的ID。
        :param pulumi.Input[builtins.str] plain: 私网Plain接入点。
        :param pulumi.Input[builtins.int] plain_port: 普通接入点端口。
        :param pulumi.Input[builtins.str] sasl: 私网SASL认证接入点。
        :param pulumi.Input[builtins.int] sasl_port: 认证接入点端口。
        :param pulumi.Input[builtins.str] ssl: 加密接入点。
        :param pulumi.Input[builtins.int] ssl_port: 加密接入点端口。
        :param pulumi.Input[builtins.str] status: 接入点状态。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if plain is not None:
            pulumi.set(__self__, "plain", plain)
        if plain_port is not None:
            pulumi.set(__self__, "plain_port", plain_port)
        if sasl is not None:
            pulumi.set(__self__, "sasl", sasl)
        if sasl_port is not None:
            pulumi.set(__self__, "sasl_port", sasl_port)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if ssl_port is not None:
            pulumi.set(__self__, "ssl_port", ssl_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_ids is not None:
            pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def plain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @plain.setter
    def plain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plain", value)

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @plain_port.setter
    def plain_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "plain_port", value)

    @property
    @pulumi.getter
    def sasl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @sasl.setter
    def sasl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sasl", value)

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @sasl_port.setter
    def sasl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "sasl_port", value)

    @property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl", value)

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @ssl_port.setter
    def ssl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_port", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")

    @vpc_ids.setter
    def vpc_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "vpc_ids", value)


if not MYPY:
    class InstanceEndpointsPublicArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[builtins.str]]
        """
        域名映射地址。
        """
        eip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        实例绑定的EIP的ID。
        """
        plain: NotRequired[pulumi.Input[builtins.str]]
        """
        私网Plain接入点。
        """
        plain_port: NotRequired[pulumi.Input[builtins.int]]
        """
        普通接入点端口。
        """
        sasl: NotRequired[pulumi.Input[builtins.str]]
        """
        私网SASL认证接入点。
        """
        sasl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        认证接入点端口。
        """
        ssl: NotRequired[pulumi.Input[builtins.str]]
        """
        加密接入点。
        """
        ssl_port: NotRequired[pulumi.Input[builtins.int]]
        """
        加密接入点端口。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        接入点状态。
        """
        vpc_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        售卖区网络关联的VPC ID列表。
        """
elif False:
    InstanceEndpointsPublicArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointsPublicArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 plain: Optional[pulumi.Input[builtins.str]] = None,
                 plain_port: Optional[pulumi.Input[builtins.int]] = None,
                 sasl: Optional[pulumi.Input[builtins.str]] = None,
                 sasl_port: Optional[pulumi.Input[builtins.int]] = None,
                 ssl: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_port: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.str] address: 域名映射地址。
        :param pulumi.Input[builtins.str] eip_id: 实例绑定的EIP的ID。
        :param pulumi.Input[builtins.str] plain: 私网Plain接入点。
        :param pulumi.Input[builtins.int] plain_port: 普通接入点端口。
        :param pulumi.Input[builtins.str] sasl: 私网SASL认证接入点。
        :param pulumi.Input[builtins.int] sasl_port: 认证接入点端口。
        :param pulumi.Input[builtins.str] ssl: 加密接入点。
        :param pulumi.Input[builtins.int] ssl_port: 加密接入点端口。
        :param pulumi.Input[builtins.str] status: 接入点状态。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if plain is not None:
            pulumi.set(__self__, "plain", plain)
        if plain_port is not None:
            pulumi.set(__self__, "plain_port", plain_port)
        if sasl is not None:
            pulumi.set(__self__, "sasl", sasl)
        if sasl_port is not None:
            pulumi.set(__self__, "sasl_port", sasl_port)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if ssl_port is not None:
            pulumi.set(__self__, "ssl_port", ssl_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_ids is not None:
            pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def plain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @plain.setter
    def plain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plain", value)

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @plain_port.setter
    def plain_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "plain_port", value)

    @property
    @pulumi.getter
    def sasl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @sasl.setter
    def sasl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sasl", value)

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @sasl_port.setter
    def sasl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "sasl_port", value)

    @property
    @pulumi.getter
    def ssl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @ssl.setter
    def ssl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl", value)

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @ssl_port.setter
    def ssl_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_port", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")

    @vpc_ids.setter
    def vpc_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "vpc_ids", value)


if not MYPY:
    class InstanceResourceTagArgsDict(TypedDict):
        tag_kvs: NotRequired[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgsDict']]]]
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
elif False:
    InstanceResourceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourceTagArgs:
    def __init__(__self__, *,
                 tag_kvs: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] type: 标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        if tag_kvs is not None:
            pulumi.set(__self__, "tag_kvs", tag_kvs)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="tagKvs")
    def tag_kvs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgs']]]]:
        return pulumi.get(self, "tag_kvs")

    @tag_kvs.setter
    def tag_kvs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceResourceTagTagKvArgs']]]]):
        pulumi.set(self, "tag_kvs", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class InstanceResourceTagTagKvArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    InstanceResourceTagTagKvArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourceTagTagKvArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class InstanceResourcesArgsDict(TypedDict):
        storage: NotRequired[pulumi.Input['InstanceResourcesStorageArgsDict']]
        """
        资源统计响应数据。
        """
elif False:
    InstanceResourcesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourcesArgs:
    def __init__(__self__, *,
                 storage: Optional[pulumi.Input['InstanceResourcesStorageArgs']] = None):
        """
        :param pulumi.Input['InstanceResourcesStorageArgs'] storage: 资源统计响应数据。
        """
        if storage is not None:
            pulumi.set(__self__, "storage", storage)

    @property
    @pulumi.getter
    def storage(self) -> Optional[pulumi.Input['InstanceResourcesStorageArgs']]:
        """
        资源统计响应数据。
        """
        return pulumi.get(self, "storage")

    @storage.setter
    def storage(self, value: Optional[pulumi.Input['InstanceResourcesStorageArgs']]):
        pulumi.set(self, "storage", value)


if not MYPY:
    class InstanceResourcesStorageArgsDict(TypedDict):
        size: NotRequired[pulumi.Input[builtins.int]]
        """
        资源大小。
        """
        unit: NotRequired[pulumi.Input[builtins.str]]
        """
        资源单位。
        """
elif False:
    InstanceResourcesStorageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceResourcesStorageArgs:
    def __init__(__self__, *,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 unit: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] size: 资源大小。
        :param pulumi.Input[builtins.str] unit: 资源单位。
        """
        if size is not None:
            pulumi.set(__self__, "size", size)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        资源大小。
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源单位。
        """
        return pulumi.get(self, "unit")

    @unit.setter
    def unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "unit", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


